@@ -1,16 +1,16 @@
 package main
 
 import (
-	"fmt"
 	"os"
 	"syscall"
 
-	"github.com/docker/libcontainer/system"
-	"github.com/docker/libcontainer/user"
+	"github.com/opencontainers/runc/libcontainer/system"
+	"github.com/opencontainers/runc/libcontainer/user"
 )
 
 // this function comes from libcontainer/init_linux.go
 // we don't use that directly because we don't want the whole namespaces package imported here
+// (also, because we need minor modifications and it's not even exported)
 
 // SetupUser changes the groups, gid, and uid for the user inside the container
 func SetupUser(u string) error {
@@ -30,21 +30,21 @@ func SetupUser(u string) error {
 	}
 	execUser, err := user.GetExecUserPath(u, &defaultExecUser, passwdPath, groupPath)
 	if err != nil {
-		return fmt.Errorf("get supplementary groups %s", err)
+		return err
 	}
 	if err := syscall.Setgroups(execUser.Sgids); err != nil {
-		return fmt.Errorf("setgroups %s", err)
+		return err
 	}
 	if err := system.Setgid(execUser.Gid); err != nil {
-		return fmt.Errorf("setgid %s", err)
+		return err
 	}
 	if err := system.Setuid(execUser.Uid); err != nil {
-		return fmt.Errorf("setuid %s", err)
+		return err
 	}
 	// if we didn't get HOME already, set it based on the user's HOME
 	if envHome := os.Getenv("HOME"); envHome == "" {
 		if err := os.Setenv("HOME", execUser.Home); err != nil {
-			return fmt.Errorf("set HOME %s", err)
+			return err
 		}
 	}
 	return nil
